agentle.agents.agent
====================

.. automodule:: agentle.agents.agent

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
      asynccontextmanager
      cast
      contextmanager
      file_parser_default_factory
      get_default_suspension_manager
      is_module_available
      run_sync
   
   .. rubric:: Classes

   .. autosummary::
   
      Agent
      AgentConfig
      AgentConfigDict
      AgentRunOutput
      AgentSkill
      Any
      AssistantMessage
      AsyncGenerator
      Authentication
      Awaitable
      BaseModel
      BytesIO
      Callable
      Capabilities
      ConfigDict
      Context
      DeveloperMessage
      DocumentCacheStore
      DocumentParser
      FilePart
      Generation
      GenerationProvider
      Generator
      InMemoryDocumentCacheStore
      MCPServerProtocol
      Mapping
      Maybe
      MessageSequence
      MutableMapping
      MutableSequence
      ParsedFile
      Path
      Prompt
      RunState
      Sequence
      SpeechToTextProvider
      StaticKnowledge
      Step
      StringIO
      SuspensionManager
      TextPart
      Tool
      ToolExecutionSuggestion
      TraceParams
      UserMessage
   
   .. rubric:: Exceptions

   .. autosummary::
   
      MaxToolCallsExceededError
      ToolSuspensionError
   